Crate zcash_encoding

Crate zcash_encoding 

Zcash binary encodings.

zcash_encoding is a library that provides common encoding and decoding operations for stable binary encodings used throughout the Zcash ecosystem.

Structs

Array
Namespace for functions that perform encoding of array contents.
CompactSize
Namespace for functions for compact encoding of integers.
Optional
Namespace for functions that perform encoding of Option values.
ReverseHex
This handles the legacy format from Bitcoin Core’s uint256::GetHex, which reverses bytes before hex encoding. zcashd applied this to all 32-byte JSON-RPC values (transaction IDs, block hashes, Sprout field elements, etc.), though non-32-byte hex values are not reversed.
Vector
Namespace for functions that perform encoding of vectors.

Constants

MAX_COMPACT_SIZE
The maximum allowed value representable as a [CompactSize]